summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorRichard M. Stallman <rms@gnu.org>1996-03-17 15:29:34 +0000
committerRichard M. Stallman <rms@gnu.org>1996-03-17 15:29:34 +0000
commit984f9444f9276131d104add18a0dc5c7a2a95332 (patch)
tree06970fa2d995ee68f2ee1bf30d839457087a7c46
parent4b064b5b661a16221b87bceeb29944199622d540 (diff)
downloademacs-984f9444f9276131d104add18a0dc5c7a2a95332.tar.gz
(comint-exec-1): Use dumb instead of unknown, for terminfo.
-rw-r--r--lisp/comint.el4
1 files changed, 2 insertions, 2 deletions
diff --git a/lisp/comint.el b/lisp/comint.el
index f0e717ec09d..fca83137fdd 100644
--- a/lisp/comint.el
+++ b/lisp/comint.el
@@ -582,13 +582,13 @@ buffer. The hook `comint-exec-hook' is run after each exec."
(nconc
;; If using termcap, we specify `emacs' as the terminal type
;; because that lets us specify a width.
;; If using terminfo, we specify `unknown' because that is
;; a defined terminal type. `emacs' is not a defined terminal type
;; and there is no way for us to define it here.
;; Some programs that use terminfo get very confused
;; if TERM is not a valid terminal type.
(if (and (boundp 'system-uses-terminfo) system-uses-terminfo)
- (list "TERM=unknown"
+ (list "TERM=dumb"
(format "COLUMNS=%d" (frame-width)))
(list "TERM=emacs"
(format "TERMCAP=emacs:co#%d:tc=unknown:" (frame-width))))
@@ -582,13 +582,13 @@ buffer. The hook `comint-exec-hook' is run after each exec."
;; If using termcap, we specify `emacs' as the terminal type
;; because that lets us specify a width.
- ;; If using terminfo, we specify `unknown' because that is
+ ;; If using terminfo, we specify `dumb' because that is
;; a defined terminal type. `emacs' is not a defined terminal type
;; and there is no way for us to define it here.